package WebGUI::i18n::English::Asset_GalleryAlbum;

our $I18N = { 
    'addArchive message' => {
        message     => 'Your files have been submitted for approval and commit. <a href="%s">Return to Album</a>',
        lastUpdated => 0,
    },
    
    'assetName' => {
        message     => 'Gallery Album',
        lastUpdated => 1131394072,
    },
    
    'cancel'    => {
        message     => "Cancel",
        lastUpdated => 0,
        context     => "Label for Cancel button",
    },
    
    'save'      => {
        message     => "Save",
        lastUpdated => 0,
        context     => "Label for Save button",
    },
    
    'rotate left' => {
        message     => "90&deg; CCW",
        lastUpdated => 1270582436,
        context     => "Label for rotate left button",
    },
    
    'rotate right' => {
        message     => "90&deg; CW",
        lastUpdated => 1270582436,
        context     => "Label for rotate right button",
    },    
    
    'save message' => {
        message     => 'Album settings saved.',
        lastUpdated => 0,
    },

    'add photo' => {
        message     => 'Add Photo',
        lastUpdated => 0,
    },

    'return to album' => {
        message     => 'Return to Album',
        lastUpdated => 0,
    },

    'delete message' => {
        message     => 'Album has been deleted. <a href="%s">Return to Gallery</a>',
        lastUpdated => 0,
    },
        
    'help common title' => {
        message     => 'Gallery Album Variables (Common)',
        lastUpdated => 0,
    },

    'help common body' => {
        message     => 'These variables are common to all views of Album assets.',
        lastUpdated => 0,
    },

    'help fileLoop title' => {
        message     => 'Gallery Album File Loop Variables',
        lastUpdated => 0,
    },

    'help fileLoop body' => {
        message     => 'These variables are common to all views that loop over files.',
        lastUpdated => 0,
    },

    'help view title' => {
        message     => 'Gallery Album View Variables',
        lastUpdated => 0,
    },

    'help view body' => {
        message     => 'These variables are on the Album View of Album assets',
        lastUpdated => 0,
    },

    'help slideshow title' => {
        message     => 'Gallery Album Slideshow Variables',
        lastUpdated => 0,
    },

    'help slideshow body' => {
        message     => 'These variables are available from the slideshow view of the Album',
        lastUpdated => 0,
    },

    'help thumbnails title' => {
        message     => 'Gallery Album Thumbnail Variables',
        lastUpdated => 0,
    },

    'help thumbnails body' => {
        message     => 'These variables are available from the thumbnails view of the Album',
        lastUpdated => 0,
    },

    'help addArchive title' => {
        message     => 'Gallery Album Add Archive Variables',
        lastUpdated => 0,
    },

    'help addArchive body' => {
        message     => 'These variables are available from the add archive view of the Album',
        lastUpdated => 0,
    },

    'help delete title' => {
        message     => 'Gallery Album Delete Variables',
        lastUpdated => 0,
    },
    
    'help delete body' => {
        message     => 'These variables are available from the delete view of the Album',
        lastUpdated => 0,
    },

    'help edit title' => {
        message     => 'Gallery Album Edit Variables',
        lastUpdated => 0,
    },
    
    'help edit body' => {
        message     => 'These variables are available from the edit view of the Album',
        lastUpdated => 0,
    },

    'help viewRss title' => {
        message     => 'Gallery Album RSS Feed Variables',
        lastUpdated => 0,
    },

    'help viewRss body' => {
        message     => 'These variables are available from the RSS feed of the Album',
        lastUpdated => 0,
    },

    'helpvar isNewAlbum' => {
        message     => 'This variable is true if the user is adding a new Album to the Gallery',
        lastUpdated => 0,
    },

    'helpvar canAddFile' => {
        message     => 'This variable is true if the user can add files to this Album.',
        lastUpdated => 0,
    },

    'helpvar canEdit' => {
        message     => 'This variable is true if the user can edit this Album.',
        lastUpdated => 0,
    },

    'helpvar url_listAlbums' => {
        message     => 'The URL to the list albums view of the parent Gallery',
        lastUpdated => 0,
    },

    'helpvar url_listAlbumsRss' => {
        message     => 'The URL to the list albums RSS of the parent Gallery',
        lastUpdated => 1201280857,
    },

    'helpvar url_listFilesForCurrentUser' => {
        message     => 'The URL to list files for the current user, part of the parent Gallery',
        lastUpdated => 0,
    },

    'helpvar url_search' => {
        message     => 'The URL to the search view of the parent Gallery.',
        lastUpdated => 0,
    },

    'helpvar url_addArchive' => {
        message     => 'The URL to add an archive of files to this Album.',
        lastUpdated => 0,
    },

    'helpvar url_addPhoto' => {
        message     => 'The URL to add a Photo asset to this Album',
        lastUpdated => 0,
    },

    'helpvar url_addNoClass' => {
        message     => 'The URL to add something to the Album. You must add 
                        the ";class=Class::Name" to the end of it.',
        lastUpdated => 0,
    },

    'helpvar url_delete' => {
        message     => 'The URL to delete this Album',
        lastUpdated => 0,
    },

    'helpvar url_edit' => {
        message     => 'The URL to edit this Album.',
        lastUpdated => 0,
    },

    'helpvar url_listFilesForOwner' => {
        message     => 'The URL to the listFilesForUser screen for the owner of this Album.',
        lastUpdated => 0,
    },

    'helpvar url_viewRss' => {
        message     => 'The URL to the RSS feed for this Album.',
        lastUpdated => 0,
    },

    'helpvar url_slideshow' => {
        message     => 'The URL to the slideshow view of this Album.',
        lastUpdated => 0,
    },

    'helpvar url_thumbnails' => {
        message     => 'The URL to the thumbnails view of this Album.',
        lastUpdated => 0,
    },

    'helpvar fileCount' => {
        message     => 'The number of files in this Album.',
        lastUpdated => 0,
    },

    'helpvar ownerUsername' => {
        message     => 'The username of the owner of this Album.',
        lastUpdated => 0,
    },

    'helpvar thumbnailUrl' => {
        message     => q{The URL for the thumbnail of the file selected as this Album's
                        thumbnail.},
        lastUpdated => 0,
    },

    'helpvar file_loop' => {
        message     => 'The loop of files on this page.',
        lastUpdated => 0,
    },

    'helpvar file_*' => {
        message     => 'The current file being viewed in the thumbnails page. All the 
                        common variables for this file are available by prefixing "file_".',
        lastUpdated => 0,
    },

    'helpvar form_start' => {
        message     => 'Start of the form',
        lastUpdated => 0,
    },

    'helpvar form_end' => {
        message     => 'End of the form',
        lastUpdated => 0,
    },

    'helpvar form_submit' => {
        message     => 'Submit the form',
        lastUpdated => 0,
    },

    'helpvar form_archive' => {
        message     => 'The archive to upload. A WebGUI::Form::File control.',
        lastUpdated => 0,
    },

    'helpvar form_keywords' => {
        message     => 'The keywords for the files being uploaded.',
        lastUpdated => 0,
    },
    
    'helpvar form_location' => {
        message     => 'The location for the files being uploaded.',
        lastUpdated => 0,
    },    

    'helpvar form_friendsOnly' => {
        message     => 'Should the file be friends only?',
        lastUpdated => 0,
    },
    
    'helpvar form_sortBy' => {
        message     => 'Property according to which photos should be sorted.',
        lastUpdated => 0,
    },    

    'helpvar url_yes' => {
        message     => 'Confirm the delete of this Album.',
        lastUpdated => 0,
    },

    'helpvar form_cancel' => {
        message     => 'Cancel the form.',
        lastUpdated => 0,
    },

    'helpvar form_title' => {
        message     => 'The title of the Album.',
        lastUpdated => 0,
    },

    'helpvar form_description' => {
        message     => 'The description of the Album.',
        lastUpdated => 0,
    },

    'helpvar file_loop edit' => {
        message     => 'This is a loop over the files for editing multiple files in the Edit Album screen',
        lastUpdated => 0,
    },

    'helpvar isAlbumThumbnail' => {
        message     => 'This is true if the file is the current album thumbnail.',
        lastUpdated => 0,
    },

    'helpvar file_loop viewRss' => {
        message     => 'This is the loop over the files for the RSS feed that includes extra vars.',
        lastUpdated => 0,
    },

    'helpvar rssDate' => {
        message     => 'The RFC2822-compliant date for the RSS feed.',
        lastUpdated => 0,
    },

    'helpvar error' => {
        message     => 'An error message to show the user. Only defined when something went wrong.',
        lastUpdated => 0,
    },

    'addArchive error too big' => {
        message     => 'The archive you are trying to upload is too big. Please try again.',
        lastUpdated => 0,
    },

    'addArchive error generic' => {
        message     => 'There was an error uploading your archive: %s',
        lastUpdated => 0,
        context     => 'Lead in to an error message from WebGUI',
    },

    'template url_addPhoto' => {
        message     => 'Add a Photo',
        lastUpdated => 0,
        context     => 'Label for URL to add a new Photo asset.',
    },

    'template url_delete' => {
        message     => 'Delete Album',
        lastUpdated => 0,
        context     => 'Label for URL to delete this Album',
    },

    'template url_edit' => {
        message     => 'Edit Album',
        lastUpdated => 0,
        context     => 'Label for URL to edit this Album',
    },

    'template url_thumbnails' => {
        message     => 'Thumbnails',
        lastUpdated => 0,
        context     => 'Label for URL to the Thumbnails view of the Album',
    },

    'template url_slideshow' => {
        message     => 'Slideshow',
        lastUpdated => 0,
        context     => 'Label for URL to the Slideshow view of the album',
    },

    'template url' => {
        message     => 'Album',
        lastUpdated => 0,
        context     => 'Label for URL to the default view of the album',
    },

    'template file creationDate' => {
        message     => 'Uploaded on',
        lastUpdated => 0,
        context     => 'Label for the creation date of the file',
    },

    'template file numberOfComments' => {
        message     => 'Comments',
        lastUpdated => 0,
        context     => 'Label for the number of comments on the file',
    },
    
    'template add' => {
        message     => "Add Album",
        lastUpdated => 1230581051,
        context     => 'To add a new album',
    },

    'template edit' => {
        message     => "Edit Album",
        lastUpdated => 1230581053,
        context     => 'To edit an existing album',
    },

    'template assetName' => {
        message     => "Album",
        lastUpdated => 0,
        context     => "The asset's name shown in templates",
    },

    'editForm title label' =>  {
        message     => 'Title',
        lastUpdated => 0,
        context     => 'Label for the "Title" property of the Album asset',
    },

    'editForm description label' => {
        message     => 'Album Description',
        lastUpdated => 0,
        context     => 'Label for the "Description" property of the Album asset',
    },

    'editForm assetIdThumbnail label' => {
        message     => 'Please select a thumbnail to represent your album.',
        lastUpdated => 0,
    },

    'template upload type' => {
        message     => 'Upload Type',
        lastUpdated => 0,
        context     => 'Label for different methods of uploading',
    },

    'template upload single' => {
        message     => 'Single File',
        lastUpdated => 0,
        context     => 'Label for uploading a single file',
    },

    'template upload archive' => {
        message     => 'Zip Archive',
        lastUpdated => 0,
        context     => 'Label for uploading an archive of files',
    },
    
    'addArchive file' => {
        message     => 'Archive',
        lastUpdated => 0,
        context     => 'Label for the file upload control of the Add Archive page',
    },

    'addArchive keywords' => {
        message     => 'Tags',
        lastUpdated => 0,
        context     => 'Label for the "keywords" field of the Add Archive page',
    },
    
    'addArchive location' => {
        message     => 'Location',
        lastUpdated => 0,
        context     => 'Label for the "location" field of the Add Archive page',
    },
    
    'addArchive friendsOnly' => {
        message     => 'Friends Only',
        lastUpdated => 0,
        context     => 'Label for the "friendsOnly" field of the Add Archive page',
    },
    
    'addArchive sortBy' => {
        message     => 'Sort By',
        lastUpdated => 0,
        context     => 'Label for the "sortBy" field of the Add Archive page',
    },

    'addArchive sortBy name' => {
        message     => 'Name',
        lastUpdated => 0,
        context     => 'Label for the "Name" radio button',
    },
    
    'addArchive sortBy date' => {
        message     => 'Date',
        lastUpdated => 0,
        context     => 'Label for the "Date" radio button',
    },
        
    'addArchive sortBy fileOrder' => {
        message     => 'File Order',
        lastUpdated => 0,
        context     => 'Label for the "File Order" radio button',
    },
    
    'template addArchive title' => {
        message     => "Add Zip Archive",
        lastUpdated => 0,
        context     => 'Title for the Add Archive page',
    },

    'template addArchive body' => {
        message     => 'This form accepts both "zip" and "tar/gzipped" archives',
        lastUpdated => 0,
        context     => 'Body text explaining what kinds of archives can be submitted',
    },

    'template delete message' => {
        message     => q{Are you sure you wish to delete this album?},
        lastUpdated => 0,
        context     => q{The message for the delete page},
    },

    'template delete no' => {
        message     => q{No},
        lastUpdated => 0,
        context     => q{Label for button to cancel the delete},
    },

    'template delete yes' => {
        message     => q{Yes},
        lastUpdated => 0,
        context     => q{Label for button to confirm the delete},
    },

    'what next' => {
        message     => q{What Next?},
        lastUpdated => 0,
        context     => 'Title for the list of actions a user can take after saving a Gallery Album',
    },

    'helpvar gallery_title' => {
        message     => q{The title of the Gallery containing this File},
        lastUpdated => 0,
        context     => q{Description of template variable},
    },

    'helpvar gallery_menuTitle' => {
        message     => q{The menu title of the Gallery containing this File},
        lastUpdated => 0,
        context     => q{Description of template variable},
    },

    'helpvar gallery_url' => {
        message     => q{The URL of the Gallery containing this File},
        lastUpdated => 0,
        context     => q{Description of template variable},
    },

    'helpvar gallery_displayTitle' => {
        message     => q{Whether the Gallery containing this File is set to display its title, or not.},
        lastUpdated => 0,
        context     => q{Description of template variable},
    },

    'helpvar isPending' => {
        message     => q{A flag to set if the GalleryAlbum is not yet approved. Users who can edit the GalleryAlbum are allowed to see them before they are approved.},
        lastUpdated => 0,
        context     => q{Description of template variable},
    },

    'helpvar form_promote' => {
        message     => q{A button to move the image up in the ranking. Use this to change the order of the images.},
        lastUpdated => 1213631348,
        context     => q{Description of template variable},
    },

    'helpvar form_demote' => {
        message     => q{A button to move the image down in the ranking. Use this to change the order of the images.},
        lastUpdated => 1213631346,
        context     => q{Description of template variable},
    },
    
    'helpvar form_rotateLeft' => {
        message     => q{A button to rotate the photo by 90&deg; counter clockwise.},
        lastUpdated => 1270582436,
        context     => q{Description of template variable},
    },
    
    'helpvar form_rotateRight' => {
        message     => q{A button to rotate the photo by 90&deg; clockwise.},
        lastUpdated => 1270582436,
        context     => q{Description of template variable},
    },    

    'helpvar form_delete' => {
        message     => q{A button to delete the image.},
        lastUpdated => 0,
        context     => q{Description of template variable},
    },

    'helpvar form_synopsis' => {
        message     => q{An HTML Area for the image thumbnail.},
        lastUpdated => 0,
        context     => q{Description of template variable},
    },

    'helpvar nextAlbum_url' => {
        message     => q{The URL to the next album in the list, in the order that is shown on the Gallery List Albums view. If there is no next album, this variable will not exist.},
        lastUpdated => 0,
        context     => q{Description of template variable},
    },

    'helpvar previousAlbum_url' => {
        message     => q{The URL to the previous album in the list, in the order that is shown on the Gallery List Albums view. If there is no previous album, this variable will not exist.},
        lastUpdated => 0,
        context     => q{Description of template variable},
    },

    'helpvar nextAlbum_title' => {
        message     => q{The title for the next album in the list.},
        lastUpdated => 0,
        context     => q{Description of template variable},
    },

    'helpvar nextAlbum_thumbnailUrl' => {
        message     => q{The URL to the thumbnail image for the next album in the list.},
        lastUpdated => 0,
        context     => q{Description of template variable},
    },

    'helpvar previousAlbum_title' => {
        message     => q{The title for the previous album in the list.},
        lastUpdated => 0,
        context     => q{Description of template variable},
    },

    'helpvar previousAlbum_thumbnailUrl' => {
        message     => q{The URL to the thumbnail image for the previous album in the list.},
        lastUpdated => 0,
        context     => q{Description of template variable},
    },

    'editForm othersCanAdd label' => {
        message     => q{Others Can Add},
        lastUpdated => 0,
        context     => q{Description of asset property to allow people besides the owner to add files to the album},
    },

    'template use as thumbnail' => {
        message     => q{Use as Album Thumbnail},
        lastUpdated => 0,
        context     => q{template label in the Edit Album template.  To pick a thumbnail to use to represent the Album.},
    },

    'template album thumbnail alt' => {
        message     => 'Preview thumbnail for',
        lastUpdated => 1237404629,
        context     => 'Alt text for album thumbnail.',
    },

    'template url_addDescription' => {
        message     => 'Add a Description',
        lastUpdated => 1237405184,
        context     => 'Label for URL to add an album Description.',
    },

    'Uploading archive' => {
        message     => 'Uploading archive',
        lastUpdated => 1237403498,
        context     => 'label for progress bar in addArchive',
    },

    'Extracting archive' => {
        message     => 'Extracting archive',
        lastUpdated => 1237403498,
        context     => 'label for progress bar in addArchive',
    },

    'Getting list of files for sorting purposes' => {
        message     => 'Getting list of files for sorting purposes',
        lastUpdated => 1237403498,
        context     => 'label for progress bar in addArchive',
    },

    'Found file: %s' => {
        message     => 'Found file %s',
        lastUpdated => 1237403498,
        context     => 'label for progress bar in addArchive',
    },

    'Adding %s to album' => {
        message     => 'Adding %s to album',
        lastUpdated => 1237403498,
        context     => 'label for progress bar in addArchive',
    },

    'Requesting commit for version tag' => {
        message     => 'Requesting commit for version tag',
        lastUpdated => 1237403498,
        context     => 'label for progress bar in addArchive',
    },

};

1;
